#delimit ;
clear all;

*************************************************
* PARAMETERS
*************************************************;
local survey_yr 2010;

local wage_r_up 0.03;
local wage_r_down -0.01;
local wage_tip_age 58;
local ret_age 65;

local first_rpi_yr 1982;
local pi_mid 0.4;
local max_age 120;

local sp_get 0.5;
local sp_get_pct 0.63;

import excel "r_aaa_bond_corp.xlsx", sheet("Moody's AAA Corp Bond Yield") cellrange(C1:E32) firstrow clear;
mkmat r_aaa_full pi_liv_full, matrix(rpi);

import excel "Period_Tables.xlsx", sheet("Male (copy)") cellrange(B2:EV122) firstrow clear;
mkmat m1860-m2010, matrix(mp);

import excel "Period_Tables.xlsx", sheet("Female (copy)") cellrange(B2:EV122) firstrow clear;
mkmat f1860-f2010, matrix(fp);

do "dbval2010.do";

use "p2010i6.dta", clear;
svmat rpi, n(col);
svmat mp, n(col);
svmat fp, n(col);

gen r_aaa = r_aaa_full[`survey_yr'-`first_rpi_yr'+1];
gen pi_liv = pi_liv_full[`survey_yr'-`first_rpi_yr'+1];

*************************************************
* WEIGHTS FOR TABULATION
*************************************************;
gen simpwt = X42001/5;

*************************************************
* DEMOGRAPHIC INFORMATION
*************************************************;
gen married = 0;
replace married = 1 if inrange(X7019,1,50);

*************************************************
* AGE CATEGORIES
*************************************************;
gen age_2534 = (X14>=25 & X14<=34) if !missing(X14);
gen age_3544 = (X14>=35 & X14<=44) if !missing(X14);
gen age_4554 = (X14>=45 & X14<=54) if !missing(X14);
gen age_5564 = (X14>=55 & X14<=64) if !missing(X14);
gen age_6064 = (X14>=60 & X14<=64) if !missing(X14);
gen age_6574 = (X14>=65 & X14<=74) if !missing(X14);
gen age_7584 = (X14>=75 & X14<=84) if !missing(X14);

gen age_cat = 0 if age_2534==1|age_3544==1|age_4554==1|age_5564==1|age_6574==1|age_7584==1;
replace age_cat = 1 if age_3544==1;
replace age_cat = 2 if age_4554==1;
replace age_cat = 3 if age_5564==1;
replace age_cat = 4 if age_6064==1;
replace age_cat = 5 if age_6574==1;
replace age_cat = 6 if age_7584==1;

label define agegp 0 "25-34" 1 "35-44" 2 "45-54" 3 "55-64" 4 "60-64" 5 "65-74" 6 "75-84";
label values age_cat agegp;

*************************************************
* RETIREMENT ACCOUNT PARTICIPATION
*************************************************;
* Individual Retirement Accounts (IRAs);
gen haveIRA = 0;
replace haveIRA = 1 if X6444==1|X6448==1 | X6446==1|X6450==1 | X6447==1|X6451==1;

* Defined Contribution Plans;
gen haveDC = 0;
replace haveDC = 1 if inrange(X11001,2,4)|X11001==6|inrange(X11001,20,22)|X11001==26
					 |inrange(X11101,2,4)|X11101==6|inrange(X11101,20,22)|X11101==26
					 |inrange(X11301,2,4)|X11301==6|inrange(X11301,20,22)|X11301==26
					 |inrange(X11401,2,4)|X11401==6|inrange(X11401,20,22)|X11401==26
					 |(inrange(X5316,1,2)&X6461==1)|(inrange(X5324,1,2)&X6466==1)
					 |(inrange(X5332,1,2)&X6471==1)|(inrange(X5416,1,2)&X6476==1)|X6957!=0
					 |X5603==2|X5611==2|X5619==2|X5627==2
					 |X5603==3|X5611==3|X5619==3|X5627==3|X6997!=0
					 |X3605==1|X3615==1;

* Defined Benefit Plans;
gen haveDB = 0;
replace haveDB = 1 if X11001==1|X11101==1|X11301==1|X11401==1
					 |(inrange(X5316,1,2)&X6461==5)|(inrange(X5324,1,2)&X6466==5)
					 |(inrange(X5332,1,2)&X6471==5)|(inrange(X5416,1,2)&X6476==5)
					 |X5603==1|X5603==3|X5611==1|X5611==3
					 |X5619==1|X5619==3|X5627==1|X5627==3;

gen haveIRADC = 0;
gen haveIRADB = 0;
gen haveDCDB = 0;
gen haveIRADCDB = 0;
replace haveIRADC = 1 if haveIRA==1 & haveDC==1;
replace haveIRADB = 1 if haveIRA==1 & haveDB==1;
replace haveDCDB = 1 if haveDC==1 & haveDB==1;
replace haveIRADCDB =1 if haveIRA==1 & haveDC==1 & haveDB==1;

gen haveAny = haveIRA|haveDC|haveDB;

*************************************************
* CURRENT AND PROJECTED ANNUAL SALARY
*************************************************;
gen w_freq_h = 0;
replace w_freq_h = X4111*5 if X4113==1;
replace w_freq_h = X4111 if X4113==2;
replace w_freq_h = X4111/2 if X4113==3;
replace w_freq_h = 12 if X4113==4;
replace w_freq_h = 4 if X4113==5;
replace w_freq_h = 1 if X4113==6;
replace w_freq_h = 2 if X4113==11;
replace w_freq_h = X4110*X4111 if X4113==18;
replace w_freq_h = 24 if X4113==31;

gen w_freq_s = 0;
replace w_freq_s = X4711*5 if X4713==1;
replace w_freq_s = X4711 if X4713==2;
replace w_freq_s = X4711/2 if X4713==3;
replace w_freq_s = 12 if X4713==4;
replace w_freq_s = 4 if X4713==5;
replace w_freq_s = 1 if X4713==6;
replace w_freq_s = 2 if X4713==11;
replace w_freq_s = X4710*X4711 if X4713==18;
replace w_freq_s = 24 if X4713==31;

gen salary_h = X4112*w_freq_h;
gen salary_s = X4712*w_freq_s;

gen salary_ret_h = salary_h*(1+`wage_r_up')^(`wage_tip_age'-X14)*(1+`wage_r_down')^(`ret_age'-`wage_tip_age');
replace salary_ret_h = salary_h*(1+`wage_r_down')^(`ret_age'-X14) if X14>`wage_tip_age';
replace salary_ret_h = salary_h if X14>`ret_age';
gen salary_ret_s = salary_s*(1+`wage_r_up')^(`wage_tip_age'-X19)*(1+`wage_r_down')^(`ret_age'-`wage_tip_age');
replace salary_ret_s = salary_h*(1+`wage_r_down')^(`ret_age'-X19) if X19>`wage_tip_age';
replace salary_ret_s = salary_s if X19>`ret_age';

*************************************************
* BALANCES IN RETIREMENT ACCOUNTS
*************************************************;
**** IRA ****;
gen iraTotVal = X6551+X6559+X6552+X6560+X6553+X6561 if haveIRA==1;

**** DC ****;
gen dcVal1a = .;
gen dcVal1b = .;
gen dcVal2a = .;
gen dcVal2b = .;
gen dcVal1  = .;
gen dcVal2  = .;
gen dcVal3  = .;
gen dcVal4  = .;
gen dcVal5  = .;
gen dcValA  = .;
gen dcValB  = .;
gen dcValC  = .;
gen dcValD  = .;
gen dcValE  = .;
gen dcValF  = .;
gen dcValG  = .;

replace dcVal1a = max(0,X11032) if inrange(X11001,2,4)|X11001==6|inrange(X11001,20,22)|X11001==26;
replace dcVal1b = max(0,X11132) if inrange(X11101,2,4)|X11101==6|inrange(X11101,20,22)|X11101==26;
replace dcVal2a = max(0,X11332) if inrange(X11301,2,4)|X11301==6|inrange(X11301,20,22)|X11301==26;
replace dcVal2b = max(0,X11432) if inrange(X11401,2,4)|X11401==6|inrange(X11401,20,22)|X11401==26;
replace dcVal1 = X6462 if (inrange(X5316,1,2)&X6461==1);
replace dcVal2 = X6467 if (inrange(X5324,1,2)&X6466==1);
replace dcVal3 = X6472 if (inrange(X5332,1,2)&X6471==1);
replace dcVal4 = X6477 if (inrange(X5416,1,2)&X6476==1);
replace dcVal5 = max(0,X6957) if X6957!=0;
replace dcValA = X5604 if X5603==2|X5603==3;
replace dcValB = X5612 if X5611==2|X5611==3;
replace dcValC = X5620 if X5619==2|X5619==3;
replace dcValD = X5628 if X5627==2|X5627==3;
replace dcValE = max(0,X6997) if X6997!=0;
replace dcValF = X6554 if X3605==1;
replace dcValG = X6562 if X3615==1;

gen dcTotVal = max(0,dcVal1a) + max(0,dcVal1b) + max(0,dcVal2a) + 
			   max(0,dcVal2b) + max(0,dcVal1) + max(0,dcVal2) + 
			   max(0,dcVal3) + max(0,dcVal4) + max(0,dcVal5) + 
			   max(0,dcValA) + max(0,dcValB) + max(0,dcValC) + 
			   max(0,dcValD) + max(0,dcValE) + max(0,dcValF) + 
			   max(0,dcValG) if haveDC==1;

**** DB ****;
gen dbVal1a = .;
gen dbVal1b = .;
gen dbVal2a = .;
gen dbVal2b = .;
gen dbVal1  = .;
gen dbVal2  = .;
gen dbVal3  = .;
gen dbVal4  = .;
gen dbVal5  = .;
gen dbValA  = .;
gen dbValB  = .;
gen dbValC  = .;
gen dbValD  = .;

mata:;
for (i=1;i<=st_nobs();i++){;

	if (st_data(i,"X11001")==1) {;
		x = genDB1a_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbVal1a",x);
	};

	if (st_data(i,"X11101")==1) {;
		x = genDB1b_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbVal1b",x);
	};

	if (st_data(i,"X11301")==1) {;
		x = genDB2a_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbVal2a",x);
	};

	if (st_data(i,"X11401")==1) {;
		x = genDB2b_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbVal2b",x);
	};

	if ((st_data(i,"X5316")==1 | st_data(i,"X5316")==2) & st_data(i,"X6461")==5) {;
		x = genDB1_2010(i,`first_rpi_yr',`max_age');
		st_store(i,"dbVal1",x);
	};

	if ((st_data(i,"X5324")==1 | st_data(i,"X5324")==2) & st_data(i,"X6466")==5) {;
		x = genDB2_2010(i,`first_rpi_yr',`max_age');
		st_store(i,"dbVal2",x);
	};

	if ((st_data(i,"X5332")==1 | st_data(i,"X5332")==2) & st_data(i,"X6471")==5) {;
		x = genDB3_2010(i,`first_rpi_yr',`max_age');
		st_store(i,"dbVal3",x);
	};

	if ((st_data(i,"X5416")==1 | st_data(i,"X5416")==2) & st_data(i,"X6476")==5) {;
		x = genDB4_2010(i,`first_rpi_yr',`max_age');
		st_store(i,"dbVal4",x);
	};

	if (st_data(i,"X6958")!=0) {;
		x = genDB5_2010(i,`first_rpi_yr',`pi_mid',`max_age');
		st_store(i,"dbVal5",x);
	};

	if (st_data(i,"X5603")==1 | st_data(i,"X5603")==3) {;
		x = genDBA_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbValA",x);
	};

	if (st_data(i,"X5611")==1 | st_data(i,"X5611")==3) {;
		x = genDBB_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbValB",x);
	};

	if (st_data(i,"X5619")==1 | st_data(i,"X5619")==3) {;
		x = genDBC_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbValC",x);
	};

	if (st_data(i,"X5627")==1 | st_data(i,"X5627")==3) {;
		x = genDBD_2010(i,`first_rpi_yr',`pi_mid',`max_age',`sp_get',`sp_get_pct');
		st_store(i,"dbValD",x);
	};

};

end;

gen dbTotVal = max(0,dbVal1a) + max(0,dbVal1b) + max(0,dbVal2a) + 
			   max(0,dbVal2b) + max(0,dbVal1) + max(0,dbVal2) + 
			   max(0,dbVal3) + max(0,dbVal4) + max(0,dbVal5) + 
			   max(0,dbValA) + max(0,dbValB) + max(0,dbValC) + 
			   max(0,dbValD) if haveDB==1;

gen IRADCTotVal = max(0,iraTotVal) + max(0,dcTotVal) if haveIRA==1|haveDC==1;

*************************************************
* % WITH RETIREMENT ACCOUNTS MEETING THRESHOLDS
*************************************************;
gen haveIRA_50k = 0;
replace haveIRA_50k = 1 if iraTotVal>=50000 & haveIRA==1;
gen haveDC_50k = 0;
replace haveDC_50k = 1 if dcTotVal>=50000 & haveDC==1;
gen haveIRADC_50k = 0;
replace haveIRADC_50k = 1 if IRADCTotVal>=50000 & (haveIRA==1|haveDC==1);
gen haveDB_50k = 0;
replace haveDB_50k = 1 if dbTotVal>=50000 & haveDB==1;

gen haveIRA_100k = 0;
replace haveIRA_100k = 1 if iraTotVal>=100000 & haveIRA==1;
gen haveDC_100k = 0;
replace haveDC_100k = 1 if dcTotVal>=100000 & haveDC==1;
gen haveIRADC_100k = 0;
replace haveIRADC_100k = 1 if IRADCTotVal>=100000 & (haveIRA==1|haveDC==1);
gen haveDB_100k = 0;
replace haveDB_100k = 1 if dbTotVal>=100000 & haveDB==1;

**************************************************************************************************
* % TABLE 11: HOUSEHOLD OWNERSHIP OF RETIREMENT ACCOUNTS AND PENSION PLANS, 2010
**************************************************************************************************;
table age_cat [pw=simpwt] if !married, c(mean iraTotVal mean dcTotVal mean IRADCTotVal mean dbTotVal);
table age_cat [pw=simpwt] if !married, c(median iraTotVal median dcTotVal median IRADCTotVal median dbTotVal);
table age_cat [pw=simpwt] if !married, c(mean haveIRA_50k mean haveDC_50k mean haveIRADC_50k mean haveDB_50k);
table age_cat [pw=simpwt] if !married, c(mean haveIRA_100k mean haveDC_100k mean haveIRADC_100k mean haveDB_100k);

table age_cat [pw=simpwt] if married, c(mean iraTotVal mean dcTotVal mean IRADCTotVal mean dbTotVal);
table age_cat [pw=simpwt] if married, c(median iraTotVal median dcTotVal median IRADCTotVal median dbTotVal);
table age_cat [pw=simpwt] if married, c(mean haveIRA_50k mean haveDC_50k mean haveIRADC_50k mean haveDB_50k);
table age_cat [pw=simpwt] if married, c(mean haveIRA_100k mean haveDC_100k mean haveIRADC_100k mean haveDB_100k);

**************************************************************************************************
* % TABLE 12: REPEATED CROSS-SECTION EVIDENCE ON EVOLUTION OF RETIREMENT PLAN PARTICIPATION, 2010
**************************************************************************************************;
table age_cat [pw=simpwt], c(mean haveDC mean haveDB mean haveAny);

**************************************************************************************************
* % TABLE 13: OVERLAP IN RETIREMENT SAVINGS VEHICLES, HOUSEHOLDS AGED 55-64, 2010
**************************************************************************************************;
table age_cat [pw=simpwt], c(mean haveIRA mean haveDC mean haveDB);
table age_cat [pw=simpwt], c(mean haveIRADC mean haveIRADB mean haveDCDB);
table age_cat [pw=simpwt], c(mean haveIRADCDB);

table age_cat [pw=simpwt] if  haveDC&!haveDB&!haveIRA, c(median dcTotVal);
table age_cat [pw=simpwt] if !haveDC& haveDB&!haveIRA, c(median dbTotVal);
table age_cat [pw=simpwt] if !haveDC&!haveDB& haveIRA, c(median iraTotVal);

table age_cat [pw=simpwt] if  haveDC& haveDB&!haveIRA, c(median dcTotVal median dbTotVal);
table age_cat [pw=simpwt] if !haveDC& haveDB& haveIRA, c(median dbTotVal median iraTotVal);
table age_cat [pw=simpwt] if  haveDC&!haveDB& haveIRA, c(median dcTotVal median iraTotVal);

table age_cat [pw=simpwt] if  haveDC& haveDB& haveIRA, c(median dcTotVal median dbTotVal median iraTotVal);
